/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 * © 2016 OX Software GmbH
 *
 * @author Daniel Rentz <daniel.rentz@open-xchange.com>
 */

define('io.ox/office/presentation/app/fileactions',
[
    'io.ox/office/editframework/app/fileactions',
     'gettext!io.ox/office/presentation/actions'
], function (FileActions, gt) {

    'use strict';

    FileActions.create('presentation', {
        newDocumentLabel: gt('New presentation'),
        newDocumentIndex: 30
    });

});
